Pastry
======

.. image:: https://secure.travis-ci.org/stephenbm/pastry.png?branch=master
    :target: http://travis-ci.org/stephenbm/pastry

.. image:: https://readthedocs.org/projects/pastry/badge/?version=latest
    :alt: Documentation Status
    :target: http://pastry.readthedocs.io/en/latest/?badge=latest
 
.. image:: https://api.codacy.com/project/badge/Grade/049731b399a04fc991e7ec8af98aac95
    :target: https://www.codacy.com/app/steve-bm/pastry?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=stephenbm/pastry&amp;utm_campaign=Badge_Grade

.. image:: https://api.codacy.com/project/badge/Coverage/049731b399a04fc991e7ec8af98aac95
    :target: https://www.codacy.com/app/steve-bm/pastry?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=stephenbm/pastry&amp;utm_campaign=Badge_Coverage   

A simple chef api wrapper

For more info, please visit the `documentation`_

.. _documentation: http://pastry.readthedocs.io/en/latest/

